"use strict";
/**
 * A `ParseFn` throws a `ParseError` when the `ParseInput` cannot be transformed to the parsers target type.
 */
class ParserError extends Error {
    constructor(expected, found) {
        super(`Expected ${expected} but found ${found}`);
        this.expected = expected;
        this.found = found;
    }
}
exports.ParserError = ParserError;
/**
 * Syntactic sugar to lazy invoke a `ParseFn`; Creates a new `ParseFn` with given parser and returns it for later
 * invocation.
 */
exports.parse = (parser) => (x) => parser(x);
